@@ -36,7 +36,7 @@ class OutputMatrix(object):
 class StepReport(object):
     __metaclass__ = ABCMeta
 
-    def __init__(self, samples, out_file, template_input_file):
+    def __init__(self, samples, template_input_file, out_file):
         self.samples = samples
         self.out_file = out_file
         self.template_input_file = self.get_step_path(template_input_file)
@@ -99,8 +99,8 @@ class StepReport(object):
 
 # Get the counts of reads.
 class CountMatrix(StepReport):
-    def __init__(self, samples, out_file, template_input_file):
-        super(CountMatrix, self).__init__(samples, out_file, template_input_file)
+    def __init__(self, samples, template_input_file, out_file):
+        super(CountMatrix, self).__init__(samples, template_input_file, out_file)
 
     def create_header(self):
         self.out_container.header.append('Gene')
@@ -118,8 +118,8 @@ class CountMatrix(StepReport):
 
 # Get the counts of non features reads.
 class NonFeatureCounts(StepReport):
-    def __init__(self, samples, out_file, template_input_file):
-        super(NonFeatureCounts, self).__init__(samples, out_file, template_input_file)
+    def __init__(self, samples, template_input_file, out_file):
+        super(NonFeatureCounts, self).__init__(samples, template_input_file, out_file)
 
     def create_header(self):
         self.out_container.header.append('Gene')
@@ -137,8 +137,8 @@ class NonFeatureCounts(StepReport):
 
 # Get statistics of cutadapt.
 class TrimStats(StepReport):
-    def __init__(self, samples, out_file, template_input_file):
-        super(TrimStats, self).__init__(samples, out_file, template_input_file)
+    def __init__(self, samples, template_input_file, out_file):
+        super(TrimStats, self).__init__(samples, template_input_file, out_file)
 
     def create_header(self):
         with open(self.template_input_file % self.samples[0]) as statf:
@@ -178,8 +178,8 @@ class TrimStats(StepReport):
 
 # Get statistics of mapping.
 class MappingStats(StepReport):
-    def __init__(self, samples, out_file, template_input_file):
-        super(MappingStats, self).__init__(samples, out_file, template_input_file)
+    def __init__(self, samples, template_input_file, out_file):
+        super(MappingStats, self).__init__(samples, template_input_file, out_file)
 
     def create_header(self):
         columns = ['Sample', 'Started job on', 'Started mapping on', 'Finished on',
@@ -204,9 +204,9 @@ class MappingStats(StepReport):
 
 
 class StarCountsStats(StepReport):
-    def __init__(self, samples, out_file, template_input_file, stranded):
+    def __init__(self, samples, template_input_file, out_file, stranded):
         self.stranded = stranded
-        super(StarCountsStats, self).__init__(samples, out_file, template_input_file)
+        super(StarCountsStats, self).__init__(samples, template_input_file, out_file)
 
     def create_header(self):
         self.out_container.header.append('Gene')
@@ -229,10 +229,13 @@ class StarCountsStats(StepReport):
             elif self.stranded == 'no':
                 return 1
             else:
-                if abs(float(first_strands) / (two_strands + 1) - 0.5) <= float(self.stranded) - 0.5:
-                    return 1
-                else:
+                min_strand = min(first_strands, second_strands)
+                max_strand = max(first_strands, second_strands)
+                if float(min_strand) / max_strand <= 0.5:  # stranded
                     return 2 if first_strands > second_strands else 3
+                else:
+                    return 1
+
 
     def read_sample_details(self, sample):
         counts_column = self.get_counts_column(sample)
@@ -269,8 +272,8 @@ class ComparingFiles(object):
         self.samples_deseq = samples_deseq
         self.factors = factors
         self.batches = None if batches == ['no-deseq'] else batches
-        self.desc_out_file = os.path.join(output_dir, 'sample_desc'+run_id+'.csv')
-        self.comp_out_file = os.path.join(output_dir, 'comparisons'+run_id+'.csv')
+        self.desc_out_file = os.path.join(output_dir, 'sample_desc_'+run_id+'.csv')
+        self.comp_out_file = os.path.join(output_dir, 'comparisons_'+run_id+'.csv')
         self.unique_desc = list(sorted(set(self.factors), key=self.factors.index))
         logging.info('Start step: %s' % self.__class__.__name__)
 
@@ -383,7 +386,7 @@ class CreateArgs(object):
     def getargs(self, indir, infile, outfile):
         template_input_file = os.path.join(self.root_dir, indir, infile)
         out_file = os.path.join(args.output_dir, outfile)
-        return (self.samples, out_file, template_input_file)
+        return (self.samples, template_input_file, out_file)
 
 
 if __name__ == '__main__':
